@@ -853,9 +853,12 @@ class TagList[T, P](Tag[Sequence[Tag[T, P]], list[P]]):
         string += "}"
         return string
 
+    def __getitem__(self, index: int) -> Tag[T, P]:
+        return self.value[index]
+
 
 @dataclass(frozen=True)
-class TagByteList[T](Tag[Sequence[int], Sequence[int]]):
+class TagByteList(Tag[Sequence[int], Sequence[int]]):
     """
     NBT tag for a list of bytes.
     """
@@ -896,6 +899,9 @@ class TagByteList[T](Tag[Sequence[int], Sequence[int]]):
         string += "}"
         return string
 
+    def __getitem__(self, index: int) -> int:
+        return self.value[index]
+
 
 @dataclass(frozen=True)
 class TagIntList(Tag[Sequence[int], Sequence[int]]):
@@ -939,6 +945,9 @@ class TagIntList(Tag[Sequence[int], Sequence[int]]):
         string += "}"
         return string
 
+    def __getitem__(self, index: int) -> int:
+        return self.value[index]
+
 
 @dataclass(frozen=True)
 class TagLongList(Tag[Sequence[int], Sequence[int]]):
@@ -982,6 +991,9 @@ class TagLongList(Tag[Sequence[int], Sequence[int]]):
         string += "}"
         return string
 
+    def __getitem__(self, index: int) -> int:
+        return self.value[index]
+
 
 @dataclass(frozen=True)
 class TagCompound[T, P](Tag[Sequence[Tag[T, P]], dict[str, P]]):
@@ -1034,6 +1046,12 @@ class TagCompound[T, P](Tag[Sequence[Tag[T, P]], dict[str, P]]):
         string += "}"
         return string
 
+    def __getitem__(self, key: str) -> Tag[T, P]:
+        for tag in self.value:
+            if tag.name == key:
+                return tag
+        raise KeyError(f"{key!r}")
+
 
 def load(
     file: IO[bytes],
